@@ -61,7 +61,6 @@ typedef struct {
 
 /* Signal IDs */
 enum {
-	LIST_PREPARED,
 	IMAGE_ADDED,
 	IMAGE_REMOVED,
 	LAST_SIGNAL
@@ -185,16 +184,6 @@ eog_image_list_class_init (EogImageListClass *klass)
 	object_class->finalize = eog_image_list_finalize;
 	object_class->dispose = eog_image_list_dispose;
 
-	eog_image_list_signals[LIST_PREPARED] = 
-		g_signal_new ("list-prepared",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EogImageListClass, list_prepared),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
 	eog_image_list_signals[IMAGE_ADDED] =
 		g_signal_new ("image-added",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -426,14 +415,14 @@ cleanup_dead_files (EogImageList *list)
 	while (node != NULL && !found) {
 		GnomeVFSURI *uri = eog_image_get_uri(node->data);
 		if (!gnome_vfs_uri_exists (uri)) {
-			remove = g_list_append (remove, (gpointer)position);
+			remove = g_list_append (remove, GINT_TO_POINTER (position));
 		}	
 		node = node->next;		
 		position++;
 	}
 
 	while (remove) {
-		gint pos = (gint)remove->data;
+		gint pos = GPOINTER_TO_INT (remove->data);
 		EogIter *iter = eog_image_list_get_iter_by_pos (list, pos);
 
 		if (iter) {
@@ -653,6 +642,8 @@ eog_image_list_add_uris (EogImageList *list, GList *uri_list)
 		
 				add_directory (list, uri, info);
 
+				gnome_vfs_uri_unref (uri);
+
 				/* If the file we explicitly requested wasn't 'found' when
 				 * scanning the directory then explicitly add it.
 				 */
