@@ -76,9 +76,6 @@ typedef struct {
 } ItemUpdate;
 
 struct _EogWrapListPrivate {
-	/* List of all items currently in the view. */
-	GHashTable *item_table;
-
 	/* Sorted list of items */
 	GList *view_order;
 
@@ -205,7 +202,6 @@ eog_wrap_list_init (EogWrapList *wlist)
 	priv = g_new0 (EogWrapListPrivate, 1);
 	wlist->priv = priv;
 	
-	priv->item_table = NULL;
 	priv->view_order = NULL;
 	priv->selected_items = NULL;
 	priv->n_selected_items = 0;
@@ -244,6 +240,17 @@ eog_wrap_list_dispose (GObject *object)
 		g_object_unref (G_OBJECT (priv->model));
 	priv->model = NULL;
 
+	if (priv->view_order) {
+		g_list_foreach (priv->view_order, (GFunc) gtk_object_destroy, NULL);
+		g_list_free (priv->view_order);
+		priv->view_order = NULL;
+	}
+
+	if (priv->selected_items) {
+		g_list_free (priv->selected_items);
+		priv->selected_items = NULL;
+	}
+
 	/* FIXME: free the items and item array */
 	
 	G_OBJECT_CLASS (eog_wrap_list_parent_class)->dispose (object);
@@ -266,18 +273,6 @@ eog_wrap_list_finalize (GObject *object)
 		(* G_OBJECT_CLASS (eog_wrap_list_parent_class)->finalize) (object);
 }
 
-static void
-eog_wrap_list_construct (EogWrapList *wlist)
-{
-	wlist->priv->item_table = g_hash_table_new ((GHashFunc) g_direct_hash, 
-						    (GCompareFunc) g_direct_equal);
-
-	g_signal_connect_after (G_OBJECT (wlist), 
-				"button-press-event",
-				G_CALLBACK (handle_canvas_click),
-				wlist);
-}
-
 
 GtkWidget*
 eog_wrap_list_new (void)
@@ -293,7 +288,11 @@ eog_wrap_list_new (void)
 				GDK_KEY_PRESS_MASK,
 				NULL);
 
-	eog_wrap_list_construct (EOG_WRAP_LIST (wlist));
+	g_signal_connect_after (G_OBJECT (wlist), 
+				"button-press-event",
+				G_CALLBACK (handle_canvas_click),
+				wlist);
+
 	
 	return wlist;
 }
