@@ -228,10 +228,9 @@ make_canonical_uri (const char *path)
 	return uri;
 }
 
-static GnomeVFSFileType
-check_uri_file_type (GnomeVFSURI *uri, GnomeVFSFileInfo *info)
+static GnomeVFSResult
+check_uri_file_type (GnomeVFSURI *uri, GnomeVFSFileInfo *info, GnomeVFSFileType *type)
 {
-	GnomeVFSFileType type = GNOME_VFS_FILE_TYPE_UNKNOWN;
 	GnomeVFSResult result;
 
 	g_return_val_if_fail (uri != NULL, GNOME_VFS_FILE_TYPE_UNKNOWN);
@@ -239,6 +238,8 @@ check_uri_file_type (GnomeVFSURI *uri, GnomeVFSFileInfo *info)
 
 	gnome_vfs_file_info_clear (info);
 	
+	*type = GNOME_VFS_FILE_TYPE_UNKNOWN;
+	
 	result = gnome_vfs_get_file_info_uri (uri, info,
 					      GNOME_VFS_FILE_INFO_DEFAULT |
 					      GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
@@ -246,10 +247,10 @@ check_uri_file_type (GnomeVFSURI *uri, GnomeVFSFileInfo *info)
 	if (result == GNOME_VFS_OK &&
 	    ((info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_TYPE) != 0))
 	{
-		type = info->type;
+		*type = info->type;
 	}
 
-	return type;
+	return result;
 }
 
 /**
@@ -274,26 +275,29 @@ sort_files (GSList *files, GList **file_list, GList **dir_list, GList **error_li
 	for (it = files; it != NULL; it = it->next) {
 		GnomeVFSURI *uri;
 		GnomeVFSFileType type = GNOME_VFS_FILE_TYPE_UNKNOWN;
+		GnomeVFSResult result;
 		char *argument;
 
 		argument = (char*) it->data;
 		uri = make_canonical_uri (argument);
 
 		if (uri != NULL) {
-			type = check_uri_file_type (uri, info);
+			result = check_uri_file_type (uri, info, &type);
 		}
 
-		switch (type) {
-		case GNOME_VFS_FILE_TYPE_REGULAR:
-			*file_list = g_list_prepend (*file_list, gnome_vfs_uri_ref (uri));
-			break;
-		case GNOME_VFS_FILE_TYPE_DIRECTORY:
-			*dir_list = g_list_prepend (*dir_list, gnome_vfs_uri_ref (uri));
-			break;
-		default:
-			*error_list = g_list_prepend (*error_list, 
-						      gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE));
-			break;
+		if (result != GNOME_VFS_ERROR_CANCELLED) {
+			switch (type) {
+			case GNOME_VFS_FILE_TYPE_REGULAR:
+				*file_list = g_list_prepend (*file_list, gnome_vfs_uri_ref (uri));
+				break;
+			case GNOME_VFS_FILE_TYPE_DIRECTORY:
+				*dir_list = g_list_prepend (*dir_list, gnome_vfs_uri_ref (uri));
+				break;
+			default:
+				*error_list = g_list_prepend (*error_list, 
+							      gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE));
+				break;
+			}
 		}
 
 		if (uri != NULL) {
@@ -400,6 +404,9 @@ job_prepare_model_do (EogJob *job, gpointer data, GError **error)
 static void
 job_prepare_model_finished (EogJob *job, gpointer data, GError *error)
 {
+	GtkWidget *dialog;
+	EogImage *image;
+	int pos;
 	LoadContext *ctx = (LoadContext*) data;
 	
 	if (eog_job_get_status (job) == EOG_JOB_STATUS_FINISHED &&
@@ -410,8 +417,25 @@ job_prepare_model_finished (EogJob *job, gpointer data, GError *error)
 		assign_model_to_window (ctx->window, ctx->img_list);
 	} 
 	else {
+		pos = eog_image_list_get_initial_pos (ctx->img_list);
+		image = eog_image_list_get_img_by_pos (ctx->img_list, pos);
+		dialog = gtk_message_dialog_new (NULL,
+						 GTK_DIALOG_DESTROY_WITH_PARENT,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 _("Couldn't load image '%s'."),
+						 eog_image_get_caption (image));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+							  error->message);
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
+		
+		g_object_unref (image);
 		g_error_free (error);
-		gtk_main_quit ();
+
+		if (eog_get_window_list () == NULL) {
+			gtk_main_quit ();
+		}
 	}
 }
 
@@ -503,7 +527,8 @@ open_uri_list_cb (EogWindow *window, GSList *uri_list, gpointer data)
 	/* open every directory in an own window */
 	if (dir_list) {
 		quit_program = FALSE;
-		load_uris_in_single_model (window, dir_list);		
+		load_uris_in_single_model (window, dir_list);
+		g_list_free (dir_list);
 	}
 
 	/* show error for inaccessable files */
@@ -540,6 +565,9 @@ handle_cmdline_args (gpointer data)
 	startup_file_list = string_array_to_list ((const gchar **) startup_files);
 	
 	open_uri_list_cb (NULL, startup_file_list, NULL);
+
+	g_slist_foreach (startup_file_list, (GFunc) g_free, NULL);
+	g_slist_free (startup_file_list);
 	
 	return FALSE;
 }
